/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Responders } from "../definitions/Responders";
import { StatusPageEntry } from "../definitions/StatusPageEntry";
export interface CreateIncidentPayload {
    /**
     * Message of the incident
     */
    message: string;
    /**
     * Description field of the incident that is generally used to provide a detailed information about the incident.
     */
    description?: string;
    /**
     * Responders that the incident will be routed to send notifications
     */
    responders?: Array<Responders>;
    /**
     * Tags of the incident.
     */
    tags?: Array<string>;
    /**
     * Map of key-value pairs to use as custom properties of the incident
     */
    details?: {
        [x: string]: string;
    };
    /**
     * Priority level of the incident
     */
    priority?: "P1" | "P2" | "P3" | "P4" | "P5";
    /**
     * Additional note that will be added while creating the incident
     */
    note?: string;
    /**
     * Services on which incident will be created.
     */
    impactedServices?: Array<string>;
    /**
     * Status page entry fields. If this field is leaved blank, message and description of incident will be used for title and detail respectively.
     */
    statusPageEntry?: StatusPageEntry;
    /**
     * Indicate whether stakeholders are notified or not. Default value is false.
     */
    notifyStakeholders?: boolean;
}
//# sourceMappingURL=CreateIncidentPayload.d.ts.map