/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { parseResponseWithLongNumbers } from "./common";
import { Blob, FormData } from "@managed-api/commons-core";
import { BaseApiCore, constructUrl, executeHttpCall, Request, Response } from "@managed-api/commons-core";
import { constructHeaders, errorMessageBuilder } from "./common";
import { customErrorHandlers, errorStrategyBuilderConstructor } from "./errorStrategy";
export class OpsgenieApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Alert = new AlertGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Incident = new IncidentGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Alert, this.Incident);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options, (_a !== null && _a !== void 0 ? _a : {})),
            errorStrategy,
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Alert, Incident) {
        this.Alert = Alert;
        this.Incident = Incident;
    }
    /**
     * Used to track the status and alert details (if any) of the request whose identifier is given
     * Alternative usage: Alert.getRequestStatus
     * Documentation: https://docs.opsgenie.com/docs/alert-api#get-request-status
     * @param options Request options.
     */
    async getRequestStatusforAlert(options) {
        return this.Alert.getRequestStatus(options);
    }
    /**
     * Returns alert with given id, tiny id or alias
     * Alternative usage: Alert.getAlert
     * Documentation: https://docs.opsgenie.com/docs/alert-api#get-alert
     * @param options Request options.
     */
    async getAlert(options) {
        return this.Alert.getAlert(options);
    }
    /**
     * Deletes an alert using alert id, tiny id or alias
     * Alternative usage: Alert.deleteAlert
     * Documentation: https://docs.opsgenie.com/docs/alert-api#delete-alert
     * @param options Request options.
     */
    async deleteAlert(options) {
        return this.Alert.deleteAlert(options);
    }
    /**
     * Returns list of alerts
     * Alternative usage: Alert.getAlerts
     * Documentation: https://docs.opsgenie.com/docs/alert-api#list-alerts
     * @param options Request options.
     */
    async getAlerts(options) {
        return this.Alert.getAlerts(options);
    }
    /**
     * Creates a new alert
     * Alternative usage: Alert.createAlert
     * Documentation: https://docs.opsgenie.com/docs/alert-api#create-alert
     * @param options Request options.
     */
    async createAlert(options) {
        return this.Alert.createAlert(options);
    }
    /**
     * Count alerts in Opsgenie
     * Alternative usage: Alert.countAlerts
     * Documentation: https://docs.opsgenie.com/docs/alert-api#count-alerts
     * @param options Request options.
     */
    async countAlerts(options) {
        return this.Alert.countAlerts(options);
    }
    /**
     * Acknowledges alert with given identifier
     * Alternative usage: Alert.acknowledgeAlert
     * Documentation: https://docs.opsgenie.com/docs/alert-api#acknowledge-alert
     * @param options Request options.
     */
    async acknowledgeAlert(options) {
        return this.Alert.acknowledgeAlert(options);
    }
    /**
     * Closes alert with given identifier
     * Alternative usage: Alert.closeAlert
     * Documentation: https://docs.opsgenie.com/docs/alert-api#close-alert
     * @param options Request options.
     */
    async closeAlert(options) {
        return this.Alert.closeAlert(options);
    }
    /**
     * Custom actions for the alert
     * Alternative usage: Alert.executeCustomAction
     * Documentation: https://docs.opsgenie.com/docs/alert-api#execute-custom-action
     * @param options Request options.
     */
    async executeCustomAlertAction(options) {
        return this.Alert.executeCustomAction(options);
    }
    /**
     * UnAcknowledge alert with given identifier
     * Alternative usage: Alert.unacknowledgeAlert
     * Documentation: https://docs.opsgenie.com/docs/alert-api#unacknowledge-alert
     * @param options Request options.
     */
    async unacknowledgeAlert(options) {
        return this.Alert.unacknowledgeAlert(options);
    }
    /**
     * Snooze alert with given identifier
     * Alternative usage: Alert.snoozeAlert
     * Documentation: https://docs.opsgenie.com/docs/alert-api#snooze-alert
     * @param options Request options.
     */
    async snoozeAlert(options) {
        return this.Alert.snoozeAlert(options);
    }
    /**
     * Escalate alert with given identifier
     * Alternative usage: Alert.escalateAlertToNext
     * Documentation: https://docs.opsgenie.com/docs/alert-api#escalate-alert-to-next
     * @param options Request options.
     */
    async escalateAlertToNext(options) {
        return this.Alert.escalateAlertToNext(options);
    }
    /**
     * Assign alert with given identifier
     * Alternative usage: Alert.assignAlert
     * Documentation: https://docs.opsgenie.com/docs/alert-api#assign-alert
     * @param options Request options.
     */
    async assignAlert(options) {
        return this.Alert.assignAlert(options);
    }
    /**
     * Add team to alert with given identifier
     * Alternative usage: Alert.addTeam
     * Documentation: https://docs.opsgenie.com/docs/alert-api#add-team-to-alert
     * @param options Request options.
     */
    async addTeamToAlert(options) {
        return this.Alert.addTeam(options);
    }
    /**
     * Add responder to alert with given identifier
     * Alternative usage: Alert.addResponder
     * Documentation: https://docs.opsgenie.com/docs/alert-api#add-responder-to-alert
     * @param options Request options.
     */
    async addResponderToAlert(options) {
        return this.Alert.addResponder(options);
    }
    /**
     * Update the priority of the alert with given identifier
     * Alternative usage: Alert.updatePriority
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#update-alert-priority
     * @param options Request options.
     */
    async updateAlertPriority(options) {
        return this.Alert.updatePriority(options);
    }
    /**
     * Update the message of the alert with given identifier
     * Alternative usage: Alert.updateMessage
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#update-alert-message
     * @param options Request options.
     */
    async updateAlertMessage(options) {
        return this.Alert.updateMessage(options);
    }
    /**
     * Update the description of the alert with given identifier
     * Alternative usage: Alert.updateDescription
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#update-alert-description
     * @param options Request options.
     */
    async updateAlertDescription(options) {
        return this.Alert.updateDescription(options);
    }
    /**
     * List alert recipients for the given alert identifier
     * Alternative usage: Alert.getRecipients
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#list-alert-recipients
     * @param options Request options.
     */
    async getAlertRecipients(options) {
        return this.Alert.getRecipients(options);
    }
    /**
     * List alert logs for the given alert identifier
     * Alternative usage: Alert.getLogs
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#list-alert-logs
     * @param options Request options.
     */
    async getAlertLogs(options) {
        return this.Alert.getLogs(options);
    }
    /**
     * Adds note to alert with given identifier
     * Alternative usage: Alert.Note.addNote
     * Documentation: https://docs.opsgenie.com/docs/alert-api#add-note-to-alert
     * @param options Request options.
     */
    async addNoteToAlert(options) {
        return this.Alert.Note.addNote(options);
    }
    /**
     * List alert notes for the given alert identifier
     * Alternative usage: Alert.Note.getNotes
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#list-alert-notes
     * @param options Request options.
     */
    async getAlertNotes(options) {
        return this.Alert.Note.getNotes(options);
    }
    /**
     * Add tags to the alert with given identifier
     * Alternative usage: Alert.Tags.addTags
     * Documentation: https://docs.opsgenie.com/docs/alert-api#add-tags-to-alert
     * @param options Request options.
     */
    async addTagsToAlert(options) {
        return this.Alert.Tags.addTags(options);
    }
    /**
     * Remove tags of the alert with given identifier
     * Alternative usage: Alert.Tags.removeTags
     * Documentation: https://docs.opsgenie.com/docs/alert-api#remove-tags-from-alert
     * @param options Request options.
     */
    async removeTagsFromAlert(options) {
        return this.Alert.Tags.removeTags(options);
    }
    /**
     * Add details to the alert with given identifier
     * Alternative usage: Alert.Details.addDetails
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#add-details-custom-properties-to-alert
     * @param options Request options.
     */
    async addDetailsToAlert(options) {
        return this.Alert.Details.addDetails(options);
    }
    /**
     * Remove details of the alert with given identifier
     * Alternative usage: Alert.Details.removeDetails
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#remove-details-custom-properties-from-alert
     * @param options Request options.
     */
    async removeDetailsFromAlert(options) {
        return this.Alert.Details.removeDetails(options);
    }
    /**
     * Create saved search with given fields
     * Alternative usage: Alert.Saved.Search.createSavedSearch
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#create-a-saved-search
     * @param options Request options.
     */
    async createSavedSearchForAlert(options) {
        return this.Alert.Saved.Search.createSavedSearch(options);
    }
    /**
     * List all saved searches
     * Alternative usage: Alert.Saved.Search.getSavedSearches
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#list-saved-searches
     * @param options Request options.
     */
    async getSavedSearchesForAlert(options) {
        return this.Alert.Saved.Search.getSavedSearches(options);
    }
    /**
     * Update saved search for the given search identifier
     * Alternative usage: Alert.Saved.Search.updateSavedSearch
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#update-saved-search
     * @param options Request options.
     */
    async updateSavedSearchForAlert(options) {
        return this.Alert.Saved.Search.updateSavedSearch(options);
    }
    /**
     * Get saved search for the given search identifier
     * Alternative usage: Alert.Saved.Search.getSavedSearch
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#get-saved-search
     * @param options Request options.
     */
    async getSavedSearchForAlert(options) {
        return this.Alert.Saved.Search.getSavedSearch(options);
    }
    /**
     * Deletes saved search using given search identifier
     * Alternative usage: Alert.Saved.Search.deleteSavedSearch
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#delete-saved-search
     * @param options Request options.
     */
    async deleteSavedSearchForAlert(options) {
        return this.Alert.Saved.Search.deleteSavedSearch(options);
    }
    /**
     * List alert attachment names and urls for related alert
     * Alternative usage: Alert.Attachment.getAttachments
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#list-alert-attachments
     * @param options Request options.
     */
    async getAlertAttachments(options) {
        return this.Alert.Attachment.getAttachments(options);
    }
    /**
     * Add Alert Attachment to related alert
     * Alternative usage: Alert.Attachment.createAttachment
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#create-alert-attachment
     * @param options Request options.
     */
    async createAlertAttachment(options) {
        return this.Alert.Attachment.createAttachment(options);
    }
    /**
     * Get alert attachment name and url for the given identifier
     * Alternative usage: Alert.Attachment.getAttachment
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#get-alert-attachment
     * @param options Request options.
     */
    async getAlertAttachment(options) {
        return this.Alert.Attachment.getAttachment(options);
    }
    /**
     * Remove alert attachment for the given identifier
     * Alternative usage: Alert.Attachment.deleteAttachment
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#delete-alert-attachment
     * @param options Request options.
     */
    async deleteAlertAttachment(options) {
        return this.Alert.Attachment.deleteAttachment(options);
    }
    /**
     * Used to track the status and incident details (if any) of the request whose identifier is given
     * Alternative usage: Incident.getRequestStatus
     * Documentation: https://docs.opsgenie.com/docs/incident-api#get-request-status
     * @param options Request options.
     */
    async getRequestStatusForIncident(options) {
        return this.Incident.getRequestStatus(options);
    }
    /**
     * Creates a new incident
     * Alternative usage: Incident.createIncident
     * Documentation: https://docs.opsgenie.com/docs/incident-api#create-incident
     * @param options Request options.
     */
    async createIncident(options) {
        return this.Incident.createIncident(options);
    }
    /**
     * Deletes an incident using incident id or the tiny id
     * Alternative usage: Incident.deleteIncident
     * Documentation: https://docs.opsgenie.com/docs/incident-api#delete-incident
     * @param options Request options.
     */
    async deleteIncident(options) {
        return this.Incident.deleteIncident(options);
    }
    /**
     * Returns incident with given id, tiny id or alias
     * Alternative usage: Incident.getIncident
     * Documentation: https://docs.opsgenie.com/docs/incident-api#get-incident
     * @param options Request options.
     */
    async getIncident(options) {
        return this.Incident.getIncident(options);
    }
    /**
     * Return list of incidents
     * Alternative usage: Incident.getIncidents
     * Documentation: https://docs.opsgenie.com/docs/incident-api#list-incidents
     * @param options Request options.
     */
    async getIncidents(options) {
        return this.Incident.getIncidents(options);
    }
    /**
     * Closes incident with given identifier
     * Alternative usage: Incident.closeIncident
     * Documentation: https://docs.opsgenie.com/docs/incident-api#close-incident
     * @param options Request options.
     */
    async closeIncident(options) {
        return this.Incident.closeIncident(options);
    }
    /**
     * Resolves incident
     * Alternative usage: Incident.resolveIncident
     * Documentation: https://docs.opsgenie.com/docs/incident-api#resolve-incident
     * @param options Request options.
     */
    async resolveIncident(options) {
        return this.Incident.resolveIncident(options);
    }
    /**
     * Reopenss incident
     * Alternative usage: Incident.reopenIncident
     * Documentation: https://docs.opsgenie.com/docs/incident-api#reopen-incident
     * @param options Request options.
     */
    async reopenIncident(options) {
        return this.Incident.reopenIncident(options);
    }
    /**
     * Add responder to incident with given identifier
     * Alternative usage: Incident.addResponder
     * Documentation: https://docs.opsgenie.com/docs/incident-api#add-responder-to-incident
     * @param options Request options.
     */
    async addResponderToIncident(options) {
        return this.Incident.addResponder(options);
    }
    /**
     * Update the priority of the incident with given identifier
     * Alternative usage: Incident.updatePriority
     * Documentation: https://docs.opsgenie.com/docs/incident-api#update-incident-priority
     * @param options Request options.
     */
    async updateIncidentPriority(options) {
        return this.Incident.updatePriority(options);
    }
    /**
     * Update the Message of the incident with given identifier
     * Alternative usage: Incident.updateMessage
     * Documentation: https://docs.opsgenie.com/docs/incident-api#update-incident-message
     * @param options Request options.
     */
    async updateIncidentMessage(options) {
        return this.Incident.updateMessage(options);
    }
    /**
     * Update the Description of the incident with given identifier
     * Alternative usage: Incident.updateDescription
     * Documentation: https://docs.opsgenie.com/docs/incident-api#update-incident-description
     * @param options Request options.
     */
    async updateIncidentDescription(options) {
        return this.Incident.updateDescription(options);
    }
    /**
     * List incident logs for the given incident identifier
     * Alternative usage: Incident.getLogs
     * Documentation: https://docs.opsgenie.com/docs/incident-api#list-incident-logs
     * @param options Request options.
     */
    async getIncidentLogs(options) {
        return this.Incident.getLogs(options);
    }
    /**
     * Returns associated alerts for incident
     * Alternative usage: Incident.Alert.getAssociatedAlerts
     * Documentation: https://docs.opsgenie.com/docs/incident-api#get-associated-alerts
     * @param options Request options.
     */
    async getAssociatedAlertsForIncident(options) {
        return this.Incident.Alert.getAssociatedAlerts(options);
    }
    /**
     * Returns responder alerts for incident
     * Alternative usage: Incident.Alert.getResponderAlerts
     * Documentation: https://docs.opsgenie.com/docs/incident-api#get-responder-alerts
     * @param options Request options.
     */
    async getResponderAlertsForIncident(options) {
        return this.Incident.Alert.getResponderAlerts(options);
    }
    /**
     * Adds note to incident with given identifier
     * Alternative usage: Incident.Note.addNote
     * Documentation: https://docs.opsgenie.com/docs/incident-api#add-note-to-incident
     * @param options Request options.
     */
    async addNoteToIncident(options) {
        return this.Incident.Note.addNote(options);
    }
    /**
     * List incident notes for the given alert identifier
     * Alternative usage: Incident.Note.getNotes
     * Documentation: https://docs.opsgenie.com/docs/incident-api#list-incident-notes
     * @param options Request options.
     */
    async getIncidentNotes(options) {
        return this.Incident.Note.getNotes(options);
    }
    /**
     * Add tags to incident with given identifier
     * Alternative usage: Incident.Tags.addTags
     * Documentation: https://docs.opsgenie.com/docs/incident-api#add-tags-to-incident
     * @param options Request options.
     */
    async addTagsToIncident(options) {
        return this.Incident.Tags.addTags(options);
    }
    /**
     * Remove tags from incident with given identifier
     * Alternative usage: Incident.Tags.removeTags
     * Documentation: https://docs.opsgenie.com/docs/incident-api#remove-tags-from-incident
     * @param options Request options.
     */
    async removeTagsFromIncident(options) {
        return this.Incident.Tags.removeTags(options);
    }
    /**
     * Add Details(Custom Properties) to Incident
     * Alternative usage: Incident.Details.addDetails
     * Documentation: https://docs.opsgenie.com/docs/incident-api#add-detailscustom-properties-to-incident
     * @param options Request options.
     */
    async addDetailsToIncident(options) {
        return this.Incident.Details.addDetails(options);
    }
    /**
     * Remove details from Incident
     * Alternative usage: Incident.Details.removeDetails
     * Documentation: https://docs.opsgenie.com/docs/incident-api#remove-detailscustom-properties-from-incident
     * @param options Request options.
     */
    async removeDetailsFromIncident(options) {
        return this.Incident.Details.removeDetails(options);
    }
    /**
     * Add Incident Timeline Entry to incident with the incident Id
     * Alternative usage: Incident.Timeline.addEntry
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#add-incident-timeline-entry
     * @param options Request options.
     */
    async addIncidentTimelineEntry(options) {
        return this.Incident.Timeline.addEntry(options);
    }
    /**
     * List incident timeline entries for the given incident Id
     * Alternative usage: Incident.Timeline.getEntries
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#list-incident-timeline-entries
     * @param options Request options.
     */
    async getIncidentTimelineEntries(options) {
        return this.Incident.Timeline.getEntries(options);
    }
    /**
     * Get incident timeline entry for the given identifier
     * Alternative usage: Incident.Timeline.getEntry
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#get-incident-timeline-entry
     * @param options Request options.
     */
    async getIncidentTimelineEntry(options) {
        return this.Incident.Timeline.getEntry(options);
    }
    /**
     * Updates incident timeline entry for the given identifier
     * Alternative usage: Incident.Timeline.updateEntry
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#update-incident-timeline-entry
     * @param options Request options.
     */
    async updateIncidentTimelineEntry(options) {
        return this.Incident.Timeline.updateEntry(options);
    }
    /**
     * Deletes incident timeline entry for the given identifier
     * Alternative usage: Incident.Timeline.deleteEntry
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#delete-incident-timeline-entry
     * @param options Request options.
     */
    async deleteIncidentTimelineEntry(options) {
        return this.Incident.Timeline.deleteEntry(options);
    }
    /**
     * Hides incident timeline entry for the given identifier
     * Alternative usage: Incident.Timeline.hideEntry
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#hide-incident-timeline-entry
     * @param options Request options.
     */
    async hideIncidentTimelineEntry(options) {
        return this.Incident.Timeline.hideEntry(options);
    }
    /**
     * Unhides incident timeline entry for the given identifier
     * Alternative usage: Incident.Timeline.unhideEntry
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#unhide-incident-timeline-entry
     * @param options Request options.
     */
    async unhideIncidentTimelineEntry(options) {
        return this.Incident.Timeline.unhideEntry(options);
    }
}
class AlertGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Note = new AlertNoteGroup(implementation, this.getGlobalErrorStrategy);
        this.Tags = new AlertTagsGroup(implementation, this.getGlobalErrorStrategy);
        this.Details = new AlertDetailsGroup(implementation, this.getGlobalErrorStrategy);
        this.Saved = new AlertSavedGroup(implementation, this.getGlobalErrorStrategy);
        this.Attachment = new AlertAttachmentGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Used to track the status and alert details (if any) of the request whose identifier is given
     * Documentation: https://docs.opsgenie.com/docs/alert-api#get-request-status
     * @param options Request options.
     */
    async getRequestStatus(options) {
        const { headers, errorStrategy, requestId } = options;
        const request = new Request("GET", `/v2/alerts/requests/${encodeURIComponent(requestId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns alert with given id, tiny id or alias
     * Documentation: https://docs.opsgenie.com/docs/alert-api#get-alert
     * @param options Request options.
     */
    async getAlert(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes an alert using alert id, tiny id or alias
     * Documentation: https://docs.opsgenie.com/docs/alert-api#delete-alert
     * @param options Request options.
     */
    async deleteAlert(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns list of alerts
     * Documentation: https://docs.opsgenie.com/docs/alert-api#list-alerts
     * @param options Request options.
     */
    async getAlerts(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/v2/alerts`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a new alert
     * Documentation: https://docs.opsgenie.com/docs/alert-api#create-alert
     * @param options Request options.
     */
    async createAlert(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/v2/alerts`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Count alerts in Opsgenie
     * Documentation: https://docs.opsgenie.com/docs/alert-api#count-alerts
     * @param options Request options.
     */
    async countAlerts(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/v2/alerts/count`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Acknowledges alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api#acknowledge-alert
     * @param options Request options.
     */
    async acknowledgeAlert(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/acknowledge`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Closes alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api#close-alert
     * @param options Request options.
     */
    async closeAlert(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/close`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Custom actions for the alert
     * Documentation: https://docs.opsgenie.com/docs/alert-api#execute-custom-action
     * @param options Request options.
     */
    async executeCustomAction(options) {
        const { body, headers, errorStrategy, identifier, actionName, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/actions/${encodeURIComponent(actionName)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * UnAcknowledge alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api#unacknowledge-alert
     * @param options Request options.
     */
    async unacknowledgeAlert(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/unacknowledge`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Snooze alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api#snooze-alert
     * @param options Request options.
     */
    async snoozeAlert(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/snooze`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Escalate alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api#escalate-alert-to-next
     * @param options Request options.
     */
    async escalateAlertToNext(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/escalate`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Assign alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api#assign-alert
     * @param options Request options.
     */
    async assignAlert(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/assign`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add team to alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api#add-team-to-alert
     * @param options Request options.
     */
    async addTeam(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/teams`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add responder to alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api#add-responder-to-alert
     * @param options Request options.
     */
    async addResponder(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/responders`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update the priority of the alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#update-alert-priority
     * @param options Request options.
     */
    async updatePriority(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/priority`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update the message of the alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#update-alert-message
     * @param options Request options.
     */
    async updateMessage(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/message`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update the description of the alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#update-alert-description
     * @param options Request options.
     */
    async updateDescription(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/description`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * List alert recipients for the given alert identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#list-alert-recipients
     * @param options Request options.
     */
    async getRecipients(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/recipients`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * List alert logs for the given alert identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#list-alert-logs
     * @param options Request options.
     */
    async getLogs(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/logs`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class AlertNoteGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Adds note to alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api#add-note-to-alert
     * @param options Request options.
     */
    async addNote(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/notes`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * List alert notes for the given alert identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#list-alert-notes
     * @param options Request options.
     */
    async getNotes(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/notes`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class AlertTagsGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Add tags to the alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api#add-tags-to-alert
     * @param options Request options.
     */
    async addTags(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/tags`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Remove tags of the alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api#remove-tags-from-alert
     * @param options Request options.
     */
    async removeTags(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/tags`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class AlertDetailsGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Add details to the alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#add-details-custom-properties-to-alert
     * @param options Request options.
     */
    async addDetails(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/details`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Remove details of the alert with given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#remove-details-custom-properties-from-alert
     * @param options Request options.
     */
    async removeDetails(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/v2/alerts/${encodeURIComponent(identifier)}/details`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class AlertSavedGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Search = new AlertSavedSearchGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class AlertSavedSearchGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Create saved search with given fields
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#create-a-saved-search
     * @param options Request options.
     */
    async createSavedSearch(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/v2/alerts/saved-searches`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * List all saved searches
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#list-saved-searches
     * @param options Request options.
     */
    async getSavedSearches(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/v2/alerts/saved-searches`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update saved search for the given search identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#update-saved-search
     * @param options Request options.
     */
    async updateSavedSearch(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("PATCH", constructUrl(`/v2/alerts/saved-searches/${encodeURIComponent(identifier)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get saved search for the given search identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#get-saved-search
     * @param options Request options.
     */
    async getSavedSearch(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v2/alerts/saved-searches/${encodeURIComponent(identifier)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes saved search using given search identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#delete-saved-search
     * @param options Request options.
     */
    async deleteSavedSearch(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/v2/alerts/saved-searches/${encodeURIComponent(identifier)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class AlertAttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * List alert attachment names and urls for related alert
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#list-alert-attachments
     * @param options Request options.
     */
    async getAttachments(options) {
        const { headers, errorStrategy, alertIdentifier, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v2/alerts/${encodeURIComponent(alertIdentifier)}/attachments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        const response = await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
        return parseResponseWithLongNumbers(response);
    }
    /**
     * Add Alert Attachment to related alert
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#create-alert-attachment
     * @param options Request options.
     */
    async createAttachment(options) {
        const { body, headers, errorStrategy, alertIdentifier, ...queryParams } = options;
        const formBody = new FormData();
        formBody.setBufferImplementation(this.implementation);
        formBody.append("indexFile", body.indexFile, "");
        formBody.append("user", body.user, "");
        formBody.append("file", new Blob(this.implementation, [body.file], {}), body.indexFile);
        const bodyBlob = formBody.getBlob();
        const request = new Request("POST", constructUrl(`/v2/alerts/${encodeURIComponent(alertIdentifier)}/attachments`, queryParams), constructHeaders(bodyBlob, headers), bodyBlob);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get alert attachment name and url for the given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#get-alert-attachment
     * @param options Request options.
     */
    async getAttachment(options) {
        const { headers, errorStrategy, alertIdentifier, attachmentId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v2/alerts/${encodeURIComponent(alertIdentifier)}/attachments/${encodeURIComponent(attachmentId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Remove alert attachment for the given identifier
     * Documentation: https://docs.opsgenie.com/docs/alert-api-continued#delete-alert-attachment
     * @param options Request options.
     */
    async deleteAttachment(options) {
        const { headers, errorStrategy, alertIdentifier, attachmentId, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/v2/alerts/${encodeURIComponent(alertIdentifier)}/attachments/${encodeURIComponent(attachmentId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IncidentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Alert = new IncidentAlertGroup(implementation, this.getGlobalErrorStrategy);
        this.Note = new IncidentNoteGroup(implementation, this.getGlobalErrorStrategy);
        this.Tags = new IncidentTagsGroup(implementation, this.getGlobalErrorStrategy);
        this.Details = new IncidentDetailsGroup(implementation, this.getGlobalErrorStrategy);
        this.Timeline = new IncidentTimelineGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Used to track the status and incident details (if any) of the request whose identifier is given
     * Documentation: https://docs.opsgenie.com/docs/incident-api#get-request-status
     * @param options Request options.
     */
    async getRequestStatus(options) {
        const { headers, errorStrategy, requestId } = options;
        const request = new Request("GET", `/v1/incidents/requests/${encodeURIComponent(requestId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a new incident
     * Documentation: https://docs.opsgenie.com/docs/incident-api#create-incident
     * @param options Request options.
     */
    async createIncident(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/v1/incidents/create`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes an incident using incident id or the tiny id
     * Documentation: https://docs.opsgenie.com/docs/incident-api#delete-incident
     * @param options Request options.
     */
    async deleteIncident(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns incident with given id, tiny id or alias
     * Documentation: https://docs.opsgenie.com/docs/incident-api#get-incident
     * @param options Request options.
     */
    async getIncident(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Return list of incidents
     * Documentation: https://docs.opsgenie.com/docs/incident-api#list-incidents
     * @param options Request options.
     */
    async getIncidents(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/v1/incidents`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Closes incident with given identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-api#close-incident
     * @param options Request options.
     */
    async closeIncident(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/close`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Resolves incident
     * Documentation: https://docs.opsgenie.com/docs/incident-api#resolve-incident
     * @param options Request options.
     */
    async resolveIncident(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/resolve`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Reopenss incident
     * Documentation: https://docs.opsgenie.com/docs/incident-api#reopen-incident
     * @param options Request options.
     */
    async reopenIncident(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/reopen`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add responder to incident with given identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-api#add-responder-to-incident
     * @param options Request options.
     */
    async addResponder(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/responders`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update the priority of the incident with given identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-api#update-incident-priority
     * @param options Request options.
     */
    async updatePriority(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/priority`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update the Message of the incident with given identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-api#update-incident-message
     * @param options Request options.
     */
    async updateMessage(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/message`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update the Description of the incident with given identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-api#update-incident-description
     * @param options Request options.
     */
    async updateDescription(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/description`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * List incident logs for the given incident identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-api#list-incident-logs
     * @param options Request options.
     */
    async getLogs(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/logs`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IncidentAlertGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns associated alerts for incident
     * Documentation: https://docs.opsgenie.com/docs/incident-api#get-associated-alerts
     * @param options Request options.
     */
    async getAssociatedAlerts(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/associated-alert-ids`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns responder alerts for incident
     * Documentation: https://docs.opsgenie.com/docs/incident-api#get-responder-alerts
     * @param options Request options.
     */
    async getResponderAlerts(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/responder-alert-ids`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IncidentNoteGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Adds note to incident with given identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-api#add-note-to-incident
     * @param options Request options.
     */
    async addNote(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/notes`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * List incident notes for the given alert identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-api#list-incident-notes
     * @param options Request options.
     */
    async getNotes(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/notes`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IncidentTagsGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Add tags to incident with given identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-api#add-tags-to-incident
     * @param options Request options.
     */
    async addTags(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/tags`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Remove tags from incident with given identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-api#remove-tags-from-incident
     * @param options Request options.
     */
    async removeTags(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/tags`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IncidentDetailsGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Add Details(Custom Properties) to Incident
     * Documentation: https://docs.opsgenie.com/docs/incident-api#add-detailscustom-properties-to-incident
     * @param options Request options.
     */
    async addDetails(options) {
        const { body, headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/details`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Remove details from Incident
     * Documentation: https://docs.opsgenie.com/docs/incident-api#remove-detailscustom-properties-from-incident
     * @param options Request options.
     */
    async removeDetails(options) {
        const { headers, errorStrategy, identifier, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/v1/incidents/${encodeURIComponent(identifier)}/details`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IncidentTimelineGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Add Incident Timeline Entry to incident with the incident Id
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#add-incident-timeline-entry
     * @param options Request options.
     */
    async addEntry(options) {
        const { body, headers, errorStrategy, incidentId } = options;
        const request = new Request("POST", `/v2/incident-timelines/${encodeURIComponent(incidentId)}/entries`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * List incident timeline entries for the given incident Id
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#list-incident-timeline-entries
     * @param options Request options.
     */
    async getEntries(options) {
        const { headers, errorStrategy, incidentId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v2/incident-timelines/${encodeURIComponent(incidentId)}/entries`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get incident timeline entry for the given identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#get-incident-timeline-entry
     * @param options Request options.
     */
    async getEntry(options) {
        const { headers, errorStrategy, incidentId, timelineEntryId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v2/incident-timelines/${encodeURIComponent(incidentId)}/entries/${encodeURIComponent(timelineEntryId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Updates incident timeline entry for the given identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#update-incident-timeline-entry
     * @param options Request options.
     */
    async updateEntry(options) {
        const { body, headers, errorStrategy, incidentId, timelineEntryId } = options;
        const request = new Request("PUT", `/v2/incident-timelines/${encodeURIComponent(incidentId)}/entries/${encodeURIComponent(timelineEntryId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes incident timeline entry for the given identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#delete-incident-timeline-entry
     * @param options Request options.
     */
    async deleteEntry(options) {
        const { headers, errorStrategy, incidentId, timelineEntryId } = options;
        const request = new Request("DELETE", `/v2/incident-timelines/${encodeURIComponent(incidentId)}/entries/${encodeURIComponent(timelineEntryId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Hides incident timeline entry for the given identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#hide-incident-timeline-entry
     * @param options Request options.
     */
    async hideEntry(options) {
        const { headers, errorStrategy, incidentId, timelineEntryId } = options;
        const request = new Request("PATCH", `/v2/incident-timelines/${encodeURIComponent(incidentId)}/entries/${encodeURIComponent(timelineEntryId)}/hide`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Unhides incident timeline entry for the given identifier
     * Documentation: https://docs.opsgenie.com/docs/incident-timeline-api#unhide-incident-timeline-entry
     * @param options Request options.
     */
    async unhideEntry(options) {
        const { headers, errorStrategy, incidentId, timelineEntryId } = options;
        const request = new Request("PATCH", `/v2/incident-timelines/${encodeURIComponent(incidentId)}/entries/${encodeURIComponent(timelineEntryId)}/unhide`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
//# sourceMappingURL=index.js.map