/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { GetRequestStatusResponseAsResponse } from "../definitions/GetRequestStatusResponseAsResponse";
import { ErrorResponseAsResponse } from "../definitions/ErrorResponseAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { GetAlertResponseAsResponse } from "../definitions/GetAlertResponseAsResponse";
import { SuccessResponseAsResponse } from "../definitions/SuccessResponseAsResponse";
import { ListAlertsResponseAsResponse } from "../definitions/ListAlertsResponseAsResponse";
import { CreateAlertPayload } from "../definitions/CreateAlertPayload";
import { GetCountAlertsResponseAsResponse } from "../definitions/GetCountAlertsResponseAsResponse";
import { AcknowledgeAlertPayload } from "../definitions/AcknowledgeAlertPayload";
import { CloseAlertPayload } from "../definitions/CloseAlertPayload";
import { ExecuteCustomAlertActionPayload } from "../definitions/ExecuteCustomAlertActionPayload";
import { UnAcknowledgeAlertPayload } from "../definitions/UnAcknowledgeAlertPayload";
import { SnoozeAlertPayload } from "../definitions/SnoozeAlertPayload";
import { EscalateAlertToNextPayload } from "../definitions/EscalateAlertToNextPayload";
import { AssignAlertPayload } from "../definitions/AssignAlertPayload";
import { AddTeamToAlertPayload } from "../definitions/AddTeamToAlertPayload";
import { AddResponderToAlertPayload } from "../definitions/AddResponderToAlertPayload";
import { UpdateAlertPriorityPayload } from "../definitions/UpdateAlertPriorityPayload";
import { UpdateAlertMessagePayload } from "../definitions/UpdateAlertMessagePayload";
import { UpdateAlertDescriptionPayload } from "../definitions/UpdateAlertDescriptionPayload";
import { ListAlertRecipientsResponseAsResponse } from "../definitions/ListAlertRecipientsResponseAsResponse";
import { ListAlertLogsResponseAsResponse } from "../definitions/ListAlertLogsResponseAsResponse";
export interface GetRequestStatusforAlertRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Universally unique identifier of the questioned request
     */
    requestId: string;
}
declare type GetRequestStatusforAlertResponseOKType = GetRequestStatusResponseAsResponse;
export interface GetRequestStatusforAlertResponseOK extends GetRequestStatusforAlertResponseOKType {
}
declare type GetRequestStatusforAlertResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetRequestStatusforAlertResponseError extends GetRequestStatusforAlertResponseErrorType {
}
export interface GetAlertRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
}
declare type GetAlertResponseOKType = GetAlertResponseAsResponse;
export interface GetAlertResponseOK extends GetAlertResponseOKType {
}
declare type GetAlertResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetAlertResponseError extends GetAlertResponseErrorType {
}
export interface DeleteAlertRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    /**
     * Display name of the request owner
     */
    user?: string;
    /**
     * Display name of the request source
     */
    source?: string;
}
declare type DeleteAlertResponseOKType = SuccessResponseAsResponse;
export interface DeleteAlertResponseOK extends DeleteAlertResponseOKType {
}
declare type DeleteAlertResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface DeleteAlertResponseError extends DeleteAlertResponseErrorType {
}
export interface GetAlertsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Search query to apply while filtering the alerts
     */
    query?: string;
    /**
     * Identifier of the saved search query to apply while filtering the alerts
     */
    searchIdentifier?: string;
    /**
     * Identifier type of the saved search query. Possible values are 'id', or 'name'
     */
    searchIdentifierType?: "id" | "name";
    /**
     * Start index of the result set (to apply pagination). Minimum value (and also default value) is 0
     */
    offset?: number;
    /**
     * Maximum number of items to provide in the result. Must be a positive integer value. Default value is 20 and maximum value is 100
     */
    limit?: number;
    /**
     * Name of the field that result set will be sorted by
     */
    sort?: "createdAt" | "updatedAt" | "tinyId" | "alias" | "message" | "status" | "acknowledged" | "isSeen" | "snoozed" | "snoozedUntil" | "count" | "lastOccurredAt" | "source" | "owner" | "integration.name" | "integration.type" | "report.ackTime" | "report.closeTime" | "report.acknowledgedBy" | "report.closedBy";
    /**
     * Sorting order of the result set
     */
    order?: "asc" | "desc";
}
declare type GetAlertsResponseOKType = ListAlertsResponseAsResponse;
export interface GetAlertsResponseOK extends GetAlertsResponseOKType {
}
declare type GetAlertsResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetAlertsResponseError extends GetAlertsResponseErrorType {
}
export interface CreateAlertRequest extends HeadersOption, ErrorStrategyOption {
    body: CreateAlertPayload;
}
declare type CreateAlertResponseOKType = SuccessResponseAsResponse;
export interface CreateAlertResponseOK extends CreateAlertResponseOKType {
}
declare type CreateAlertResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface CreateAlertResponseError extends CreateAlertResponseErrorType {
}
export interface CountAlertsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Search query to apply while filtering the alerts
     */
    query?: string;
    /**
     * Identifier of the saved search query to apply while filtering the alerts
     */
    searchIdentifier?: string;
    /**
     * Identifier type of the saved search query. Possible values are id and name. Default value is id. If searchIdentifier is not provided, this value is ignored.
     */
    searchIdentifierType?: "id" | "name";
}
declare type CountAlertsResponseOKType = GetCountAlertsResponseAsResponse;
export interface CountAlertsResponseOK extends CountAlertsResponseOKType {
}
declare type CountAlertsResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface CountAlertsResponseError extends CountAlertsResponseErrorType {
}
export interface AcknowledgeAlertRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    body: AcknowledgeAlertPayload;
}
declare type AcknowledgeAlertResponseOKType = SuccessResponseAsResponse;
export interface AcknowledgeAlertResponseOK extends AcknowledgeAlertResponseOKType {
}
declare type AcknowledgeAlertResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface AcknowledgeAlertResponseError extends AcknowledgeAlertResponseErrorType {
}
export interface CloseAlertRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    body: CloseAlertPayload;
}
declare type CloseAlertResponseOKType = SuccessResponseAsResponse;
export interface CloseAlertResponseOK extends CloseAlertResponseOKType {
}
declare type CloseAlertResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface CloseAlertResponseError extends CloseAlertResponseErrorType {
}
export interface ExecuteCustomAlertActionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Name of the action to execute
     */
    actionName: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    body: ExecuteCustomAlertActionPayload;
}
declare type ExecuteCustomAlertActionResponseOKType = SuccessResponseAsResponse;
export interface ExecuteCustomAlertActionResponseOK extends ExecuteCustomAlertActionResponseOKType {
}
declare type ExecuteCustomAlertActionResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface ExecuteCustomAlertActionResponseError extends ExecuteCustomAlertActionResponseErrorType {
}
export interface UnacknowledgeAlertRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    body: UnAcknowledgeAlertPayload;
}
declare type UnacknowledgeAlertResponseOKType = SuccessResponseAsResponse;
export interface UnacknowledgeAlertResponseOK extends UnacknowledgeAlertResponseOKType {
}
declare type UnacknowledgeAlertResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface UnacknowledgeAlertResponseError extends UnacknowledgeAlertResponseErrorType {
}
export interface SnoozeAlertRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    body: SnoozeAlertPayload;
}
declare type SnoozeAlertResponseOKType = SuccessResponseAsResponse;
export interface SnoozeAlertResponseOK extends SnoozeAlertResponseOKType {
}
declare type SnoozeAlertResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface SnoozeAlertResponseError extends SnoozeAlertResponseErrorType {
}
export interface EscalateAlertToNextRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    body: EscalateAlertToNextPayload;
}
declare type EscalateAlertToNextResponseOKType = SuccessResponseAsResponse;
export interface EscalateAlertToNextResponseOK extends EscalateAlertToNextResponseOKType {
}
declare type EscalateAlertToNextResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface EscalateAlertToNextResponseError extends EscalateAlertToNextResponseErrorType {
}
export interface AssignAlertRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    body: AssignAlertPayload;
}
declare type AssignAlertResponseOKType = SuccessResponseAsResponse;
export interface AssignAlertResponseOK extends AssignAlertResponseOKType {
}
declare type AssignAlertResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface AssignAlertResponseError extends AssignAlertResponseErrorType {
}
export interface AddTeamToAlertRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    body: AddTeamToAlertPayload;
}
declare type AddTeamToAlertResponseOKType = SuccessResponseAsResponse;
export interface AddTeamToAlertResponseOK extends AddTeamToAlertResponseOKType {
}
declare type AddTeamToAlertResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface AddTeamToAlertResponseError extends AddTeamToAlertResponseErrorType {
}
export interface AddResponderToAlertRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    body: AddResponderToAlertPayload;
}
declare type AddResponderToAlertResponseOKType = SuccessResponseAsResponse;
export interface AddResponderToAlertResponseOK extends AddResponderToAlertResponseOKType {
}
declare type AddResponderToAlertResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface AddResponderToAlertResponseError extends AddResponderToAlertResponseErrorType {
}
export interface UpdateAlertPriorityRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    body: UpdateAlertPriorityPayload;
}
declare type UpdateAlertPriorityResponseOKType = SuccessResponseAsResponse;
export interface UpdateAlertPriorityResponseOK extends UpdateAlertPriorityResponseOKType {
}
declare type UpdateAlertPriorityResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface UpdateAlertPriorityResponseError extends UpdateAlertPriorityResponseErrorType {
}
export interface UpdateAlertMessageRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    body: UpdateAlertMessagePayload;
}
declare type UpdateAlertMessageResponseOKType = SuccessResponseAsResponse;
export interface UpdateAlertMessageResponseOK extends UpdateAlertMessageResponseOKType {
}
declare type UpdateAlertMessageResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface UpdateAlertMessageResponseError extends UpdateAlertMessageResponseErrorType {
}
export interface UpdateAlertDescriptionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    body: UpdateAlertDescriptionPayload;
}
declare type UpdateAlertDescriptionResponseOKType = SuccessResponseAsResponse;
export interface UpdateAlertDescriptionResponseOK extends UpdateAlertDescriptionResponseOKType {
}
declare type UpdateAlertDescriptionResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface UpdateAlertDescriptionResponseError extends UpdateAlertDescriptionResponseErrorType {
}
export interface GetAlertRecipientsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
}
declare type GetAlertRecipientsResponseOKType = ListAlertRecipientsResponseAsResponse;
export interface GetAlertRecipientsResponseOK extends GetAlertRecipientsResponseOKType {
}
declare type GetAlertRecipientsResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetAlertRecipientsResponseError extends GetAlertRecipientsResponseErrorType {
}
export interface GetAlertLogsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    identifierType?: "id" | "alias" | "tiny";
    /**
     * Starting value of the offset property
     */
    offset?: string;
    /**
     * Page direction to apply for the given offset with 'next' and 'prev'
     */
    direction?: "next" | "prev";
    /**
     * Maximum number of items to provide in the result. Must be a positive integer value. Default value is 20 and maximum value is 100
     */
    limit?: number;
    /**
     * Sorting order of the result set
     */
    order?: "asc" | "desc";
}
declare type GetAlertLogsResponseOKType = ListAlertLogsResponseAsResponse;
export interface GetAlertLogsResponseOK extends GetAlertLogsResponseOKType {
}
declare type GetAlertLogsResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetAlertLogsResponseError extends GetAlertLogsResponseErrorType {
}
export {};
//# sourceMappingURL=alert.d.ts.map