/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ListAlertAttachmentsResponseAsResponse } from "../../definitions/ListAlertAttachmentsResponseAsResponse";
import { ErrorResponseAsResponse } from "../../definitions/ErrorResponseAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { SuccessResponseAsResponse } from "../../definitions/SuccessResponseAsResponse";
import { GetAlertAttachmentResponseAsResponse } from "../../definitions/GetAlertAttachmentResponseAsResponse";
export interface GetAlertAttachmentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    alertIdentifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    alertIdentifierType?: "id" | "alias" | "tiny";
    /**
     * Sorting order of the result set
     */
    order?: "asc" | "desc";
    /**
     * Starting value of the offset property
     */
    offset?: string;
    /**
     * Page direction to apply for the given offset with 'next' and 'prev'
     */
    direction?: "next" | "prev";
    /**
     * Maximum number of items to provide in the result. Must be a positive integer value.
     */
    limit?: number;
}
declare type GetAlertAttachmentsResponseOKType = ListAlertAttachmentsResponseAsResponse;
export interface GetAlertAttachmentsResponseOK extends GetAlertAttachmentsResponseOKType {
}
declare type GetAlertAttachmentsResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetAlertAttachmentsResponseError extends GetAlertAttachmentsResponseErrorType {
}
export interface CreateAlertAttachmentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    alertIdentifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    alertIdentifierType?: "id" | "alias" | "tiny";
    body: {
        /**
         * Display name of the request owner
         */
        user?: string;
        /**
         * Attachment file to be uploaded
         */
        file: ArrayBuffer | string;
        /**
         * Name of html file which will be shown when attachment clicked on UI
         */
        indexFile: string;
    };
}
declare type CreateAlertAttachmentResponseOKType = SuccessResponseAsResponse;
export interface CreateAlertAttachmentResponseOK extends CreateAlertAttachmentResponseOKType {
}
declare type CreateAlertAttachmentResponseErrorType = ErrorResponseAsResponse;
export interface CreateAlertAttachmentResponseError extends CreateAlertAttachmentResponseErrorType {
}
export interface GetAlertAttachmentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    alertIdentifier: string;
    /**
     * Identifier of alert attachment
     */
    attachmentId: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    alertIdentifierType?: "id" | "alias" | "tiny";
}
declare type GetAlertAttachmentResponseOKType = GetAlertAttachmentResponseAsResponse;
export interface GetAlertAttachmentResponseOK extends GetAlertAttachmentResponseOKType {
}
declare type GetAlertAttachmentResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetAlertAttachmentResponseError extends GetAlertAttachmentResponseErrorType {
}
export interface DeleteAlertAttachmentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of alert which could be alert id, tiny id or alert alias
     */
    alertIdentifier: string;
    /**
     * Identifier of alert attachment
     */
    attachmentId: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id', 'alias' or 'tiny'
     */
    alertIdentifierType?: "id" | "alias" | "tiny";
    /**
     * Display name of the request owner
     */
    user?: string;
}
declare type DeleteAlertAttachmentResponseOKType = SuccessResponseAsResponse;
export interface DeleteAlertAttachmentResponseOK extends DeleteAlertAttachmentResponseOKType {
}
declare type DeleteAlertAttachmentResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface DeleteAlertAttachmentResponseError extends DeleteAlertAttachmentResponseErrorType {
}
export {};
//# sourceMappingURL=attachment.d.ts.map