/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { GetIncidentRequestStatusResponseAsResponse } from "../definitions/GetIncidentRequestStatusResponseAsResponse";
import { ErrorResponseAsResponse } from "../definitions/ErrorResponseAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { CreateIncidentPayload } from "../definitions/CreateIncidentPayload";
import { SuccessResponseAsResponse } from "../definitions/SuccessResponseAsResponse";
import { GetIncidentResponseAsResponse } from "../definitions/GetIncidentResponseAsResponse";
import { ListIncidentsResponseAsResponse } from "../definitions/ListIncidentsResponseAsResponse";
import { CloseIncidentPayload } from "../definitions/CloseIncidentPayload";
import { Responders } from "../definitions/Responders";
import { BaseResponseAsResponse } from "../definitions/BaseResponseAsResponse";
import { PageDetailsAsResponse } from "../definitions/PageDetailsAsResponse";
export interface GetRequestStatusForIncidentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Universally unique identifier of the questioned request
     */
    requestId: string;
}
declare type GetRequestStatusForIncidentResponseOKType = GetIncidentRequestStatusResponseAsResponse;
export interface GetRequestStatusForIncidentResponseOK extends GetRequestStatusForIncidentResponseOKType {
}
declare type GetRequestStatusForIncidentResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetRequestStatusForIncidentResponseError extends GetRequestStatusForIncidentResponseErrorType {
}
export interface CreateIncidentRequest extends HeadersOption, ErrorStrategyOption {
    body: CreateIncidentPayload;
}
declare type CreateIncidentResponseOKType = SuccessResponseAsResponse;
export interface CreateIncidentResponseOK extends CreateIncidentResponseOKType {
}
declare type CreateIncidentResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface CreateIncidentResponseError extends CreateIncidentResponseErrorType {
}
export interface DeleteIncidentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of incident which could be incident id or tiny id
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id' or 'tiny. Default is id'
     */
    identifierType?: "id" | "tiny";
}
declare type DeleteIncidentResponseOKType = SuccessResponseAsResponse;
export interface DeleteIncidentResponseOK extends DeleteIncidentResponseOKType {
}
declare type DeleteIncidentResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface DeleteIncidentResponseError extends DeleteIncidentResponseErrorType {
}
export interface GetIncidentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of incident which could be incident id or tiny id
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id' or 'tiny. Default is id'
     */
    identifierType?: "id" | "tiny";
}
declare type GetIncidentResponseOKType = GetIncidentResponseAsResponse;
export interface GetIncidentResponseOK extends GetIncidentResponseOKType {
}
declare type GetIncidentResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetIncidentResponseError extends GetIncidentResponseErrorType {
}
export interface GetIncidentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Search query to apply while filtering the incidents.
     */
    query?: string;
    /**
     * Start index of the result set (to apply pagination). Minimum value (and also default value) is 0.
     */
    offset?: number;
    /**
     * Maximum number of items to provide in the result. Must be a positive integer value. Default value is 20 and maximum value is 100
     */
    limit?: number;
    /**
     * Name of the field that result set will be sorted by
     */
    sort?: "createdAt" | "tinyId" | "status" | "isSeen" | "insertedAt" | "updatedAt" | "priority" | "postmortemStatus" | "postmortemPublishDueDate";
    /**
     * Sorting order of the result set
     */
    order?: "asc" | "desc";
}
declare type GetIncidentsResponseOKType = ListIncidentsResponseAsResponse;
export interface GetIncidentsResponseOK extends GetIncidentsResponseOKType {
}
declare type GetIncidentsResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetIncidentsResponseError extends GetIncidentsResponseErrorType {
}
export interface CloseIncidentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of incident which could be incident id or tiny id
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id' or 'tiny. Default is id'
     */
    identifierType?: "id" | "tiny";
    body: CloseIncidentPayload;
}
declare type CloseIncidentResponseOKType = SuccessResponseAsResponse;
export interface CloseIncidentResponseOK extends CloseIncidentResponseOKType {
}
declare type CloseIncidentResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface CloseIncidentResponseError extends CloseIncidentResponseErrorType {
}
export interface ResolveIncidentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of incident which could be incident id or tiny id
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id' or 'tiny. Default is id'
     */
    identifierType?: "id" | "tiny";
    body: {
        /**
         * Incident note to add
         */
        note?: string;
    };
}
declare type ResolveIncidentResponseOKType = SuccessResponseAsResponse;
export interface ResolveIncidentResponseOK extends ResolveIncidentResponseOKType {
}
declare type ResolveIncidentResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface ResolveIncidentResponseError extends ResolveIncidentResponseErrorType {
}
export interface ReopenIncidentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of incident which could be incident id or tiny id
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id' or 'tiny. Default is id'
     */
    identifierType?: "id" | "tiny";
    body: {
        /**
         * Incident note to add
         */
        note?: string;
    };
}
declare type ReopenIncidentResponseOKType = SuccessResponseAsResponse;
export interface ReopenIncidentResponseOK extends ReopenIncidentResponseOKType {
}
declare type ReopenIncidentResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface ReopenIncidentResponseError extends ReopenIncidentResponseErrorType {
}
export interface AddResponderToIncidentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of incident which could be incident id or tiny id
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id' or 'tiny. Default is id'
     */
    identifierType?: "id" | "tiny";
    body: {
        /**
         * Incident note to add
         */
        note?: string;
        /**
         * Teams and users that the incident will be routed.type field is mandatory for each item, where possible values are team and user.
         */
        responder: Array<Responders>;
    };
}
declare type AddResponderToIncidentResponseOKType = SuccessResponseAsResponse;
export interface AddResponderToIncidentResponseOK extends AddResponderToIncidentResponseOKType {
}
declare type AddResponderToIncidentResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface AddResponderToIncidentResponseError extends AddResponderToIncidentResponseErrorType {
}
export interface UpdateIncidentPriorityRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of incident which could be incident id or tiny id
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id' or 'tiny. Default is id'
     */
    identifierType?: "id" | "tiny";
    body: {
        /**
         * Priority of the incident
         */
        priority: "P1" | "P2" | "P3" | "P4" | "P5";
    };
}
declare type UpdateIncidentPriorityResponseOKType = SuccessResponseAsResponse;
export interface UpdateIncidentPriorityResponseOK extends UpdateIncidentPriorityResponseOKType {
}
declare type UpdateIncidentPriorityResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface UpdateIncidentPriorityResponseError extends UpdateIncidentPriorityResponseErrorType {
}
export interface UpdateIncidentMessageRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of incident which could be incident id or tiny id
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id' or 'tiny. Default is id'
     */
    identifierType?: "id" | "tiny";
    body: {
        /**
         * Message of the incident
         */
        message: string;
    };
}
declare type UpdateIncidentMessageResponseOKType = SuccessResponseAsResponse;
export interface UpdateIncidentMessageResponseOK extends UpdateIncidentMessageResponseOKType {
}
declare type UpdateIncidentMessageResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface UpdateIncidentMessageResponseError extends UpdateIncidentMessageResponseErrorType {
}
export interface UpdateIncidentDescriptionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of incident which could be incident id or tiny id
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id' or 'tiny. Default is id'
     */
    identifierType?: "id" | "tiny";
    body: {
        /**
         * Description of the incident.
         */
        description: string;
    };
}
declare type UpdateIncidentDescriptionResponseOKType = SuccessResponseAsResponse;
export interface UpdateIncidentDescriptionResponseOK extends UpdateIncidentDescriptionResponseOKType {
}
declare type UpdateIncidentDescriptionResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface UpdateIncidentDescriptionResponseError extends UpdateIncidentDescriptionResponseErrorType {
}
export interface GetIncidentLogsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of incident which could be incident id or tiny id
     */
    identifier: string;
    /**
     * Type of the identifier that is provided as an in-line parameter. Possible values are 'id' or 'tiny. Default is id'
     */
    identifierType?: "id" | "tiny";
    /**
     * Sorting order of the result set
     */
    order?: "asc" | "desc";
    /**
     * Starting value of the offset property
     */
    offset?: string;
    /**
     * Page direction to apply for the given offset with 'next' and 'prev'
     */
    direction?: "next" | "prev";
    /**
     * Maximum number of items to provide in the result. Must be a positive integer value. Default value is 20 and maximum value is 100
     */
    limit?: number;
}
export declare type GetIncidentLogsResponseOK = BaseResponseAsResponse & {
    data?: Array<{
        log?: string;
        type?: string;
        owner?: string;
        createdAt?: string;
        offset?: string;
    }>;
    paging?: PageDetailsAsResponse;
};
declare type GetIncidentLogsResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetIncidentLogsResponseError extends GetIncidentLogsResponseErrorType {
}
export {};
//# sourceMappingURL=incident.d.ts.map