/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BaseResponseAsResponse } from "../../definitions/BaseResponseAsResponse";
import { IncidentTimelineEntryAsResponse } from "../../definitions/IncidentTimelineEntryAsResponse";
import { ErrorResponseAsResponse } from "../../definitions/ErrorResponseAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { SuccessResponseAsResponse } from "../../definitions/SuccessResponseAsResponse";
export interface AddIncidentTimelineEntryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of the incident
     */
    incidentId: string;
    body: {
        /**
         * The description of incident timeline.
         */
        description: {
            /**
             * Only plain_text value is valid for now.
             */
            type?: "plain_text";
            /**
             * Timeline entry description.
             */
            content: string;
        };
        /**
         * Time of the incident timeline entry.
         */
        time?: string;
    };
}
export declare type AddIncidentTimelineEntryResponseOK = BaseResponseAsResponse & {
    data?: IncidentTimelineEntryAsResponse;
};
declare type AddIncidentTimelineEntryResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface AddIncidentTimelineEntryResponseError extends AddIncidentTimelineEntryResponseErrorType {
}
export interface GetIncidentTimelineEntriesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of the incident
     */
    incidentId: string;
    /**
     * Returns entries with related groups. Can be given as list.  Possible values are: custom, incident, responderAlert, stakeholderUpdate, statusPage, iccSessionLifecycle, iccSessionDetails, integration
     */
    group?: Array<string>;
    /**
     * If true, returns only unhidden entries.
     */
    discardHidden?: boolean;
    /**
     * Sorting order of the result set
     */
    order?: "asc" | "desc";
    /**
     * Starting value of the offset property
     */
    offset?: string;
    /**
     * Page direction to apply for the given offset with 'next' and 'prev'
     */
    direction?: "next" | "prev";
    /**
     * Maximum number of items to provide in the result. Must be a positive integer value. Default value is 20 and maximum value is 20
     */
    limit?: number;
    /**
     * Type of the content. Possible value and the default value is plain_text only. Will be extended later.
     */
    contentType?: "plain_text";
}
export declare type GetIncidentTimelineEntriesResponseOK = BaseResponseAsResponse & {
    data?: {
        entries?: Array<IncidentTimelineEntryAsResponse>;
        nextOffset?: string;
    };
};
declare type GetIncidentTimelineEntriesResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetIncidentTimelineEntriesResponseError extends GetIncidentTimelineEntriesResponseErrorType {
}
export interface GetIncidentTimelineEntryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of the related incident.
     */
    incidentId: string;
    /**
     * Identifier of the incident timeline entry.
     */
    timelineEntryId: string;
    /**
     * Type of the content. Possible value and the default value is plain_text only. Will be extended later.
     */
    contentType?: "plain_text";
}
export declare type GetIncidentTimelineEntryResponseOK = BaseResponseAsResponse & {
    data?: IncidentTimelineEntryAsResponse;
};
declare type GetIncidentTimelineEntryResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetIncidentTimelineEntryResponseError extends GetIncidentTimelineEntryResponseErrorType {
}
export interface UpdateIncidentTimelineEntryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of the related incident.
     */
    incidentId: string;
    /**
     * Identifier of the incident timeline entry.
     */
    timelineEntryId: string;
    body: {
        /**
         * The description of incident timeline.
         */
        description?: {
            /**
             * Only plain_text value is valid for now.
             */
            type?: "plain_text";
            /**
             * Timeline entry description.
             */
            content?: string;
        };
        /**
         * Time of the incident timeline entry.
         */
        time?: string;
    };
}
export declare type UpdateIncidentTimelineEntryResponseOK = BaseResponseAsResponse & {
    data?: IncidentTimelineEntryAsResponse;
};
declare type UpdateIncidentTimelineEntryResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface UpdateIncidentTimelineEntryResponseError extends UpdateIncidentTimelineEntryResponseErrorType {
}
export interface DeleteIncidentTimelineEntryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of the related incident.
     */
    incidentId: string;
    /**
     * Identifier of the incident timeline entry.
     */
    timelineEntryId: string;
}
declare type DeleteIncidentTimelineEntryResponseOKType = SuccessResponseAsResponse;
export interface DeleteIncidentTimelineEntryResponseOK extends DeleteIncidentTimelineEntryResponseOKType {
}
declare type DeleteIncidentTimelineEntryResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface DeleteIncidentTimelineEntryResponseError extends DeleteIncidentTimelineEntryResponseErrorType {
}
export interface HideIncidentTimelineEntryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of the related incident.
     */
    incidentId: string;
    /**
     * Identifier of the incident timeline entry.
     */
    timelineEntryId: string;
}
declare type HideIncidentTimelineEntryResponseOKType = SuccessResponseAsResponse;
export interface HideIncidentTimelineEntryResponseOK extends HideIncidentTimelineEntryResponseOKType {
}
declare type HideIncidentTimelineEntryResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface HideIncidentTimelineEntryResponseError extends HideIncidentTimelineEntryResponseErrorType {
}
export interface UnhideIncidentTimelineEntryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Identifier of the related incident.
     */
    incidentId: string;
    /**
     * Identifier of the incident timeline entry.
     */
    timelineEntryId: string;
}
declare type UnhideIncidentTimelineEntryResponseOKType = SuccessResponseAsResponse;
export interface UnhideIncidentTimelineEntryResponseOK extends UnhideIncidentTimelineEntryResponseOKType {
}
declare type UnhideIncidentTimelineEntryResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface UnhideIncidentTimelineEntryResponseError extends UnhideIncidentTimelineEntryResponseErrorType {
}
export {};
//# sourceMappingURL=timeline.d.ts.map